import Layout from '@/layout/index.vue'
/**
 *
 * ModelManage                  模型管理
 * BasicData                    基础数据管理
 * SystemConfig                 系统设置
 */

export default [
  {
    name: 'System',
    path: '/system',
    redirect: '/system/',
    component: Layout,
    meta: {
      title: '系统管理',
      icon: 'el-icon-s-platform'
    },
    children: [
      /**
       * ----------------------------模型管理-----------------------------
       */
      {
        name: 'ModelManage',
        path: '/modelManage',
        meta: {
          parent: 'System',
          title: '模型管理'
        }
      },
      {
        name: 'AgloManage',
        path: '/agloManage',
        component: () => import('@/views/als/model/index.vue'),
        meta: {
          parent: 'ModelManage',
          title: '机务算法模型管理'
        }
      },
      {
        name: 'CarrierComputationalModel',
        path: '/carrierStandard/carrierComputationalModel',
        component: () => import('@/views/carrierStandard/carrierComputationalModel/index.vue'),
        meta: {
          parent: 'ModelManage',
          title: '航材计算模型管理'
        }
      },
      /**
       * ----------------------------基础数据-----------------------------
       */
      {
        name: 'BasicData',
        path: '/basicData',
        meta: {
          parent: 'System',
          title: '基础数据'
        }
      },
      {
        name: 'DataType',
        path: '/basicData/dataType',
        component: () => import('@/views/basicData/dataType/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '机种管理'
        }
      },
      {
        name: 'DataSpecies',
        path: '/basicData/dataSpecies',
        component: () => import('@/views/basicData/dataSpecies/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '机型管理'
        }
      },
      {
        name: 'AirConfiguration',
        path: '/dataManage/airConfiguration',
        component: () => import('@/views/als/airConfiguration/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '构型管理'
        }
      },
      {
        name: 'DataAircraftCataloging',
        path: '/basicData/dataAircraftCataloging',
        component: () => import('@/views/basicData/dataAircraftCataloging/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '飞机编目管理'
        }
      },
      {
        name: 'AirInstall',
        path: '/dataManage/airInstall',
        component: () => import('@/views/als/airInstall/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '装机管理'
        }
      },
      {
        name: 'DataSailingMaterialClassification',
        path: '/basicData/dataSailingMaterialClassification',
        component: () => import('@/views/basicData/dataSailingMaterialClassification/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '航材分类管理'
        }
      },
      {
        name: 'DataSailingMaterialMaterialCoding',
        path: '/basicData/dataSailingMaterialMaterialCoding',
        component: () => import('@/views/basicData/dataSailingMaterialMaterialCoding/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '航材物资编目-机务'
        }
      },
      {
        name: 'DataSailingMaterialMaterialCodingAviation',
        path: '/basicData/dataSailingMaterialMaterialCodingAviation',
        component: () => import('@/views/basicData/dataSailingMaterialMaterialCodingAviation/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '航材物资编目-航材'
        }
      },
      {
        name: 'DataSailingMaterialPrice',
        path: '/basicData/dataSailingMaterialPrice',
        component: () => import('@/views/basicData/dataSailingMaterialPrice/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '航材价格管理'
        }
      },
      /**
       * ----------------------------基础数据(环境因子管理)-----------------------------
       */
      {
        name: 'DataEnvironment',
        path: '/basicData/dataEnvironment',
        component: () => import('@/views/basicData/dataEnvironment/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '环境因子管理'
        }
      },
      {
        name: 'DataEnvironment',
        path: '/basicData/dataEnvironment/:id/:name/:value',
        component: () => import('@/views/basicData/dataEnvironment/suitableSpareParts.vue'),
        meta: {
          parent: 'System',
          roleMenuHide: true,
          navHide: true,
          title: '环境因子管理-适用航材'
        }
      },
      /**
       * ----------------------------基础数据(航材消耗规律管理)-----------------------------
       */
      {
        name: 'CarrierSailingMaterialConsumeRegularities',
        path: '/carrierStandard/carrierSailingMaterialConsumeRegularities',
        component: () => import('@/views/carrierStandard/carrierSailingMaterialConsumeRegularities/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '航材消耗规律管理'
        }
      },
      /**
       * ----------------------------基础数据(历年航材消耗数据)-----------------------------
       */
      {
        name: 'CarrierSailingMaterialConsumeRecord',
        path: '/carrierStandard/carrierSailingMaterialConsumeRecord',
        component: () => import('@/views/carrierStandard/carrierSailingMaterialConsumeRecord/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '历年航材消耗数据'
        }
      },
      {
        name: 'CarrierSailingMaterialConsumeRecord',
        path: '/carrierStandard/carrierSailingMaterialConsumeRecord/outboundRecord/:consumeDataId',
        component: () => import('@/views/carrierStandard/carrierSailingMaterialConsumeRecord/outboundRecord.vue'),
        meta: {
          parent: 'System',
          roleMenuHide: true,
          navHide: true,
          title: '历年航材消耗数据-出库记录'
        }
      },
      {
        name: 'CarrierSailingMaterialConsumeRecord',
        path: '/carrierStandard/carrierSailingMaterialConsumeRecord/warehousingRecord/:consumeDataId',
        component: () => import('@/views/carrierStandard/carrierSailingMaterialConsumeRecord/warehousingRecord.vue'),
        meta: {
          parent: 'System',
          roleMenuHide: true,
          navHide: true,
          title: '历年航材消耗数据-入库记录'
        }
      },
      {
        name: 'CarrierSailingMaterialConsumeRecord',
        path: '/carrierStandard/carrierSailingMaterialConsumeRecord/summarizedCalculation/:consumeDataId',
        component: () => import('@/views/carrierStandard/carrierSailingMaterialConsumeRecord/summarizedCalculation.vue'),
        meta: {
          parent: 'System',
          roleMenuHide: true,
          navHide: true,
          title: '历年航材消耗数据-汇总计算'
        }
      },
      {
        name: 'PreResult',
        path: '/qualityManage/preProcessing',
        component: () => import('@/views/als/preProcessing/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '数据预处理'
        }
      },
      {
        name: 'FlightData',
        path: '/dataManage/flightData',
        component: () => import('@/views/als/flightData/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '飞参数据'
        }
      },
      {
        name: 'JudgeFaultLogic',
        path: '/dataManage/judgeFaultLogic',
        component: () => import('@/views/als/judgeFaultLogic/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '判故逻辑管理'
        }
      },
      {
        name: 'AirConfigParams',
        path: '/dataManage/AirConfigParams',
        component: () => import('@/views/als/airConfigParams/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '构型参数管理'
        }
      },
      {
        name: 'AtlasFile',
        path: '/knowledgeGraph/atlasFile',
        component: () => import('@/views/als/atlasFile/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '文件管理'
        }
      },
      {
        name: 'KnowledgeExtraction',
        path: '/knowledgeGraph/knowledgeExtraction',
        component: () => import('@/views/als/knowledgeExtraction/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '知识抽取'
        }
      },
      // {
      //   name: 'ExtractList',
      //   path: '/knowledgeGraph/extractList',
      //   component: () => import('@/views/als/knowledgeExtraction/extractList.vue'),
      //   name: 'ExtractList',
      //   meta: {
      //     parent: 'BasicData',
      //     title: '抽取列表'
      //   }
      // },
      {
        name: 'EntityManage',
        path: '/knowledgeGraph/entityManage',
        component: () => import('@/views/als/knowledgeManage/entityManage/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '实体管理'
        }
      },
      {
        name: 'ERManage',
        path: '/knowledgeGraph/ERManage',
        component: () => import('@/views/als/knowledgeManage/ERManage/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '实体关系管理'
        }
      },
      // {
      //   name: 'TrainingData',
      //   path: '/dataManage/trainingData',
      //   component: () => import('@/views/als/trainingData/index.vue'),
      //   meta: {
      //     parent: 'BasicData',
      //     title: '故障数据统计'
      //   }
      // },
      /**
       * ----------------------------基础数据(定检任务)-----------------------------
       */
      {
        name: 'SmTask',
        path: '/dataManage/smTask',
        component: () => import('@/views/als/smTask/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '定检任务'
        }
      },
      {
        name: 'SmTask',
        path: '/dataManage/smTask/SMTaskDetails',
        component: () => import('@/views/als/smTask/SMTaskDetails.vue'),
        meta: {
          parent: 'System',
          roleMenuHide: true,
          navHide: true,
          title: '任务分配',
          hide: true
        }
      },
      /**
       * ----------------------------基础数据(数据字典)-----------------------------
       */
      {
        name: 'SystemDataDictionary',
        path: '/system/systemDataDictionary',
        component: () => import('@/views/system/systemDataDictionary/index.vue'),
        meta: {
          parent: 'BasicData',
          title: '数据字典'
        }
      },
      {
        name: 'SystemDataDictionary',
        path: '/system/systemDataDictionary/:dictId',
        component: () => import('@/views/system/systemDataDictionary/data.vue'),
        meta: {
          parent: 'System',
          roleMenuHide: true,
          navHide: true,
          title: '字典数据'
        }
      },

      /**
       * ----------------------------系统设置-----------------------------
       */
      {
        name: 'SystemConfig',
        path: '/systemConfig',
        meta: {
          parent: 'System',
          title: '系统设置'
        }
      },
      {
        name: 'SystemDept',
        path: '/system/dept',
        component: () => import('@/views/system/dept/index.vue'),
        meta: {
          parent: 'SystemConfig',
          title: '组织机构管理'
        }
      },
      {
        name: 'SystemUser',
        path: '/system/user',
        component: () => import('@/views/system/user/index.vue'),
        meta: {
          parent: 'SystemConfig',
          title: '用户管理'
        }
      },
      {
        name: 'SystemRole',
        path: '/system/role',
        component: () => import('@/views/system/role/index.vue'),
        meta: {
          parent: 'SystemConfig',
          title: '角色管理'
        }
      },
      {
        name: 'SystemLog',
        path: '/system/systemLog',
        component: () => import('@/views/system/systemLog/index.vue'),
        meta: {
          parent: 'SystemConfig',
          title: '日志信息'
        }
      },
      {
        name: 'SystemBackup',
        path: '/system/systemBackup',
        component: () => import('@/views/system/systemBackup/index.vue'),
        meta: {
          parent: 'SystemConfig',
          title: '系统备份'
        }
      },
      {
        name: 'SystemCommunication',
        path: '/system/systemCommunication',
        component: () => import('@/views/als/systemCommunication/index.vue'),
        meta: {
          parent: 'SystemConfig',
          title: '通讯管理'
        }
      }
    ]
  }
]
